@@ -8,7 +8,7 @@
 
 #include "RcppThread/RMonitor.hpp"
 #include "RcppThread/Rcout.hpp"
-// #include "RcppThread/Rcerr.hpp"
+#include "RcppThread/Rcerr.hpp"
 #include "RcppThread/quickpool.hpp"
 
 #include <atomic>
@@ -81,7 +81,10 @@ inline ThreadPool::ThreadPool(size_t nWorkers)
 {}
 
 //! destructor joins all threads if possible.
-inline ThreadPool::~ThreadPool() noexcept {}
+inline ThreadPool::~ThreadPool() noexcept
+{
+    this->wait();
+}
 
 //! Access to the global thread pool instance.
 inline ThreadPool&
@@ -233,12 +236,12 @@ ThreadPool::wait()
     do {
         pool_->wait(100);
         Rcout << "";
-        // Rcerr << "";
+        Rcerr << "";
         checkUserInterrupt();
 
     } while (!pool_->done());
     Rcout << "";
-    // Rcerr << "";
+    Rcerr << "";
 }
 
 //! waits for all jobs to finish.
